@@ -384,6 +384,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
     def retrieve(self, request, *args, **kwargs):
         print('retrieve')
         print(str(request.path_info))
+
         accessory = Accessory.objects.get(**kwargs)
         calibrations = accessory.calibration_set.all()
         accessory_form = AccessoryForm(instance=accessory)
@@ -397,11 +398,7 @@ class AccessoryViewSet(viewsets.ModelViewSet):
             data_transformer = accessory.datatransformer
             formset = datatransformerset(instance=data_transformer)
         else:
-            data_transformer = DataTransformer()
-            data_transformer.accessory = accessory
-            data_transformer.save()
-            accessory = Accessory.objects.get(**kwargs)
-            data_transformer = accessory.datatransformer
+            data_transformer = DataTransformer.objects.create(accessory=accessory)
             formset = datatransformerset(instance=data_transformer)
 
         if request.accepted_renderer.format == 'html':
